@@ -1,7 +1,7 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python
 
 """
-Copyright (c) 2006-2019 sqlmap developers (http://sqlmap.org/)
+Copyright (c) 2006-2021 sqlmap developers (http://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
@@ -18,9 +18,9 @@ def tamper(payload, **kwargs):
 
     References:
         * http://www.utf8-chartable.de/unicode-utf8-table.pl?start=65280&number=128
-        * http://lukasz.pilorz.net/testy/unicode_conversion/
-        * http://sla.ckers.org/forum/read.php?13,11562,11850
-        * http://lukasz.pilorz.net/testy/full_width_utf/index.phps
+        * https://web.archive.org/web/20130614183121/http://lukasz.pilorz.net/testy/unicode_conversion/
+        * https://web.archive.org/web/20131121094431/sla.ckers.org/forum/read.php?13,11562,11850
+        * https://web.archive.org/web/20070624194958/http://lukasz.pilorz.net/testy/full_width_utf/index.phps
 
     >>> tamper("1 AND '1'='1")
     '1 AND %EF%BC%871%EF%BC%87=%EF%BC%871'
